| Title: | A-Efficiency for Nested Partially Balanced Bipartite Block (NPBBB) Designs |
|---|---|
| Description: | Nested Partially Balanced Bipartite Block (NPBBB) designs involve two levels of blocking: (i) The block design (ignoring sub-block classification) serves as a partially balanced bipartite block (PBBB) design, and (ii) The sub-block design (ignoring block classification) also serves as a PBBB design. More details on constructions of the PBBB designs and their characterization properties are available in Vinayaka et al.(2023) <doi:10.1080/03610926.2023.2251623>. This package calculates A-efficiency values for both block and sub-block structures, along with all parameters of a given NPBBB design. |
| Authors: | Vinayaka [aut, cre], B.N. Mandal [aut, ctb], Rajender Parsad [aut, ctb], Vinaykumar L.N. [aut, ctb] |
| Maintainer: | Vinayaka <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-16 06:11:50 UTC |
| Source: | https://github.com/cran/NPBBBDAefficiency |
This function calculates the A-efficiency values for the block and sub-block structures of a given NPBBB design
NPBBBD_Aeff(bd, sbd, v1, v2)NPBBBD_Aeff(bd, sbd, v1, v2)
bd |
Block design (ignoring sub-blocks) in matrix form considering rows as blocks |
sbd |
Sub-block design (ignoring blocks) in matrix form considering rows as blocks |
v1 |
Number of test treatments |
v2 |
Number of control treatments |
The output includes:
v1: Number of test treatments
v2: Number of controls
b1: Number of blocks
b2: Number of sub-blocks
r1: Test replications
r2: Control replications
k1: Block size
k2: Sub-block size
Lambdas1: Lambda values from block design
Lambdas2: Lambda values from sub-block design
E1: Block design efficiency
E2: Sub-block design efficiency
Vinayaka, Parsad R, Mandal BN, Dash S, LN Vinaykumar, Kumar M, Singh DR (2023) <doi:10.1080/03610926.2023.2251623>
## Not run: library(NPBBBDAefficiency) NPBBBD_Aeff(matrix(c(1, 2, 3, 4), nrow = 2, byrow = TRUE), matrix(c(1, 2, 3, 4), nrow = 2, byrow = TRUE), v1 = 2, v2 = 2) ## End(Not run)## Not run: library(NPBBBDAefficiency) NPBBBD_Aeff(matrix(c(1, 2, 3, 4), nrow = 2, byrow = TRUE), matrix(c(1, 2, 3, 4), nrow = 2, byrow = TRUE), v1 = 2, v2 = 2) ## End(Not run)